@@ -55,5 +55,8 @@ def qualityassurance(variable, time, **kwargs):
     if "individual_check" in kwargs:
         qa[qa_individual(time, **kwargs["individual_check"])] = 1
 
+    if "moving_average_limit" in kwargs:
+        qa[qa_moving_average_limit(variable, **kwargs["moving_average_limit"])] = 1
+
     return qa
 
